MatchMakerMonitoring.on_first_hide() — alfred3_interact

Skip to main content
`Ctrl`+`K`

# MatchMakerMonitoring.on_first_hide()

MatchMakerMonitoring.on_first_hide()

  Executed once, when the page is hidden for the first time, before executing `on_each_hide()`.

  Hook for code that is meant to be executed only once, when the page is hidden for the first time, before saving the page’s data.

  Notes

  Note the difference to `on_close()`, which is executed upon final submission of the page’s data. When using `on_first_hide()`, subject input can change (e.g., when a subject revists a page and changes his/her input).

  See also

  See “How to use hooks” for a how to on using hooks and an overview of available hooks.